<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik op het systeemvakpictogram
of druk nogmaals op de sneltoets om te stoppen</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Scherm niet draaien tijdens opname</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Opname</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Scherm vastleggen</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Het opslaan is mislukt. Sla het op in je persoonlijke map.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>De schermfoto is genomen</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Gebied selecteren</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Klembord</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Bezig met opslaan van schermopname...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>De opname moet worden gestopt omdat vensteranimaties moeten worden uitgeschakeld</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollende schermfoto</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Schermfoto&apos;s vastmaken</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Schermopname voltooid en gekopieerd naar het klembord</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Schermfoto&apos;s vastmaken</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Opname</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>De opname is afgerond</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Map openen</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Het scherm wordt over %1 seconden vastgelegd</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Verkrijg hulp.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>De scrollende schermfoto kan niet worden gemaakt.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>De onderkant van het scrollgebied is bereikt</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>De maximale lengte is bereikt</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>het vastleggebied aan te passen</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scroll met je muis of klik om een scrollende schermfoto te maken</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Verlaag de scrollsnelheid</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Ongeldig gebied; klik om het</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Voer hier tekst in</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Starten/Schermfoto</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Afsluiten/Opslaan</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Afmetingen aanpassen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inleiding</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Schermfoto van venster</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Vertraging gebruiken</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Schermfoto van volledig scherm</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechthoek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Potlood</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Verhogen (bovenkant)</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Verhogen (onderkant)</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Verbreden (links)</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Verbreden (rechts)</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Verlagen (bovenkant)</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Verlagen (onderkant)</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Versmallen (links)</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Versmallen (rechts)</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Toetsaanslag</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Opname starten</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Gereedschap</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Tekst extraheren</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollende schermfoto</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Schermfoto&apos;s vastmaken</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Ocr maken</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Scrollende schermfoto maken</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pijl</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rechthoek
Houd Shift ingedrukt om een vierkant te trekken</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ovaal
Houd Shift ingedrukt om een cirkel te trekken</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Kwast
Houd Shift ingedrukt om een rechte lijn te trekken</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Vervagingssterkte aanpassen (met scrolwiel)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Kwastgrootte aanpassen (met scrolwiel)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Tekstgrootte aanpassen (met scrolwiel)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Toetsaanslagen tonen (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Toetsaanslagen verbergen (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Toetsaanslagen tonen (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Camera aanzetten (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Camera uitzetten (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Instellingen (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfoon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Systeemgeluid</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Cursor vastleggen</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Muisklikken tonen</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Opslaan op/in</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Lijn (L)
Houd Shift ingedrukt om een verticale of horizontale lijn te trekken</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Pijl (X)
Houd Shift ingedrukt om een verticale of horizontale pijl te tekenen</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Potlood (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Vervagen (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Tekst (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollende schermfoto (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Tekst extraheren (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Schermfoto&apos;s vastmaken (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Ongedaan maken (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Locatie kiezen na klikken op opslaan</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Locatie wijzigen na klikken op opslaan</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Randeffecten</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Schaduw</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Kader</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Apparaat</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Tekst extraheren</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Geometrische hulpmiddelen (R)
Houd Shift ingedrukt om vierkanten of cirkels te tekenen.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Opslaan naar lokale map</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Opslaan naar bureaublad</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Opslaan naar afbeeldingen</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Opslaan naar %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Specifieke locatie</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>Aangepaste locatie</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>Elke vraag</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>Locatie bijwerken bij opslaan</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>Opslaan naar bureaublad</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>Opslaan naar afbeeldingen</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Sluiten (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Kopiëren naar klembord (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Verhoog de resolutie van het opnamegebied naar %1*%2 voor een betere opname</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Schermopname wordt momenteel niet ondersteund</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
</TS>
